@@ -24,37 +24,41 @@ utils::globalVariables(c("invDRIFT","II","DRIFTexp","vec2diag","diag2vec",
   'T0VAR','T0MEANS', 'MANIFESTTRAITVAR',
   'TDpredNames', 'TIpredNames', 'Tpoints', 'extract', 'latentNames', 'manifestNames',
   'plot', 'points','T0TRAITEFFECT',
-  'T0VARsubindex','DRIFTsubindex','DIFFUSIONsubindex','CINTsubindex'))
+  'T0VARsubindex','DRIFTsubindex','DIFFUSIONsubindex','CINTsubindex','.'))
 
-`:=` = function(...) NULL
-`.` = function(...) NULL
-.N = id = grp = NULL # due to NSE notes in R CMD check
+if(1==99){
+  `:=` = NULL
+  `.` =NULL
+  .N = .id = id= . = grp = NULL # due to NSE notes in R CMD check
+}
 
 
 #' ctsem
 #' 
 #' ctsem is an R package for continuous time structural equation modelling of panel (N > 1) 
-#' and time series (N = 1) data, using either a frequentist or Bayesian approach. 
-#' The frequentist approach is faster but can only estimate random-effects on the intercepts, 
-#' while the Bayesian approach allows for random-effects across all model parameters. 
-#' 
+#' and time series (N = 1) data, using either a frequentist or Bayesian approach, or middle
+#' ground forms like maximum a posteriori. 
+#'  
 #' The general workflow begins by specifying a model using the \code{\link{ctModel}} function, 
 #' in which the \code{type} of model is also specified. Then the model is fit to data using 
-#' either \code{\link{ctFit}} if an 'omx' (OpenMx, frequentist) model is specified or 
-#' \code{\link{ctStanFit}} if a 'stanct' or 'standt' (Stan, continuous / discrete time, Bayesian)
-#' model is specified. 
-#' For examples, see either \code{\link{ctFit}} or \code{\link{ctStanFit}}. 
-#' For more detailed information, see the frequentist vignette by running: \code{vignette('ctsem')} 
+#' \code{\link{ctStanFit}}. The ctFit function which allows for fitting using the OpenMx / SEM form,
+#' as described in the original JSS ctsem paper, can now be found in the ctsemOMX package.  
+#' The omx forms are no longer in 
+#' development and for most purposes, the newer stan based forms are more robust and flexible.
+#' For examples, see  \code{\link{ctStanFit}}. 
 #' For citation info, please run \code{citation('ctsem')} .
 #'  
 #' @docType package
 #' @name ctsem
-#' @import grDevices methods stats rstan OpenMx graphics rstantools Rcpp data.table ggplot2
+#' @import grDevices methods stats graphics data.table ggplot2
+#' @import Rcpp
+#' @importFrom RcppParallel CxxFlags RcppParallelLibs
+#' @import expm expm
+#' @importFrom rstan constrain_pars sampling unconstrain_pars stan_model log_prob monitor get_num_upars stanc get_sampler_params As.mcmc.list monitor
 #' @importFrom plyr aaply alply round_any
 #' @importFrom utils relist as.relistable tail capture.output
 #' @importFrom Deriv Simplify 
 #' @importFrom cOde jacobianSymb prodSymb
-#' @importFrom quantreg qss
 #' @useDynLib ctsem, .registration = TRUE
 #' 
 #' @references 
@@ -69,7 +73,7 @@ NULL
 
 .onAttach <- function(libname, pkgname) {
   # to show a startup message
-  packageStartupMessage("ctsem also changes in time, for an up to date manual run function ctDocs(), for citation info see citation('ctsem')")
+  packageStartupMessage("ctsem also changes in time, for manual run ctDocs(), for blog see https://cdriver.netlify.app/, for citation info run citation('ctsem'), for original OpenMx functionality install.packages('ctsemOMX')")
 }
 
 #' Get documentation pdf for ctsem
@@ -78,14 +82,35 @@ NULL
 #' @export
 #'
 #' @examples
-#' \donttest{
 #' ctDocs()
-#' }
 ctDocs <- function(){
+  if(interactive()){
   r=runif(1,0,9999999)
-  pdfpath=paste0(tempdir(),'\\ctsemManual_',r,'.pdf')
+  pdfpath=file.path(tempdir(),paste0('/ctsemManual_',r,'.pdf'))
   utils::download.file(url="https://github.com/cdriveraus/ctsem/raw/master/vignettes/hierarchicalmanual.pdf",
     destfile=pdfpath,mode='wb')
   try(openPDF(pdfpath))
+  }
+}
+
+#' ctFit function placeholder
+#' 
+#' For the original ctsem OpenMx functionality, the package ctsemOMX should be loaded.
+#'
+#' @param ... arguments to pass to ctFit, if ctsemOMX is loaded.
+#'
+#' @return message or fit object.
+#' @export
+#'
+#' @examples
+#' data(AnomAuth) 
+#' AnomAuthmodel <- ctModel(LAMBDA = matrix(c(1, 0, 0, 1), nrow = 2, ncol = 2), 
+#' Tpoints = 5, n.latent = 2, n.manifest = 2, MANIFESTVAR=diag(0, 2), TRAITVAR = NULL) 
+#' AnomAuthfit <- ctFit(AnomAuth, AnomAuthmodel)
+ctFit <- function(...){
+  if('ctsemOMX' %in% utils::installed.packages()[,1]){
+    if(!'ctsemOMX' %in% (.packages())){
+      message('for original ctsem functionality using OpenMx, please load: library(ctsemOMX)')
+    } else eval(parse(text=paste0('ctsemOMX::ctFit(...)'))) #one time hack due to package splitting, forgive my soul...
+  } else message('For original ctsem functionality using OpenMx, install.packages("ctsemOMX")')  
 }
-  
