@@ -1,5 +1,5 @@
 .onLoad <- function(libname, pkgname) {
-  if(.Machine$sizeof.pointer > 4){
+  if(.Machine$sizeof.pointer > 4 || .Platform$OS.type!='windows'){
     modules <- paste0("stan_fit4", names(stanmodels), "_mod")
     for (m in modules) loadModule(m, what = TRUE)
   }
